@@ -12,7 +12,7 @@
 # You should have received a copy of the CC0 legalcode along with this
 # work.  If not, see <http://creativecommons.org/publicdomain/zero/1.0/>.
 
-__all__ = ['magma', 'inferno', 'plasma', 'viridis']
+__all__ = ['magma', 'inferno', 'plasma', 'viridis', 'cmaps']
 
 _magma_data = [[0.001462, 0.000466, 0.013866],
                [0.002258, 0.001295, 0.018331],
