@@ -1,3 +1,4 @@
+from _ast import operator
 from abc import abstractmethod, ABC
 import sys
 import random
@@ -70,7 +71,7 @@ class Evaluator(Operator):
         self.algorithm.problem.individuals.append(individual)
 
         self.job.evaluate(individual)
-        return individual.costs[0]
+        return individual.costs_signed[0]
 
 
 class GradientEvaluator(Evaluator):
@@ -120,16 +121,17 @@ class GradientEvaluator(Evaluator):
                 gradient[i] = ((child.costs[0] - individual.costs[0]) / self.delta)
                 i += 1
             individual.features['gradient'] = gradient
-            if any(gradient < 0):
-                sensitivity = 1000
-            else:
-                sensitivity = sum(abs(gradient))
-            if len(individual.costs) > self.n:
-                individual.costs[-1] = sensitivity
-                individual.costs_signed[-2] = sensitivity
-            else:
-                individual.costs.append(sensitivity)
-                individual.costs_signed.insert(-1, sensitivity)
+
+            # if any(gradient < 0):
+            #     sensitivity = 1000
+            # else:
+            #     sensitivity = sum(abs(gradient))
+            # if len(individual.costs) > self.n:
+            #     individual.costs[-1] = sensitivity
+            #     individual.costs_signed[-2] = sensitivity
+            # else:
+            #     individual.costs.append(sensitivity)
+            #     individual.costs_signed.insert(-1, sensitivity)
 
         self.individuals = []
         self.to_evaluate = []
@@ -231,7 +233,7 @@ class UniformGenerator(Generator):
             vectors.append([])
             delta = (parameter['bounds'][1] - parameter['bounds'][0]) / (self.number - 1)
             for i in range(self.number):
-                vectors[-1].append(parameter['bounds'][0] + i*delta)
+                vectors[-1].append(parameter['bounds'][0] + i * delta)
 
         for combination in itertools.product(*vectors):
             individuals.append(Individual(list(combination), self.features))
@@ -255,6 +257,30 @@ class RandomGenerator(Generator):
         return individuals
 
 
+class IntegerGenerator(Generator):
+    """
+    Generate Integer vectors for problems with discrete values
+    """
+
+    def __init__(self, parameters, features=dict()):
+        super().__init__(parameters, features)
+        # self.parameters['parameter_type'] = 'integer'
+        self.number = 0
+
+    def init(self, number, parameters):
+        self.number = number
+        for parameter in parameters:
+            if not ('parameter_type' in parameter):
+                parameter['parameter_type'] = 'integer'
+
+    def generate(self):
+        individuals = []
+        for i in range(self.number):
+            vector = VectorAndNumbers.gen_vector(self.parameters)
+            individuals.append(Individual(vector, self.features))
+        return individuals
+
+
 class FullFactorGenerator(Generator):
     """
     Create a general full-factorial design
@@ -1355,7 +1381,7 @@ class FireflyStep(Operator):
               Engineering with computers, 29(2), 175-184.
     """
 
-    def __init__(self, parameters, alpha = 0.01, beta = 1.0, gamma = 0.5, damping = 0.9, dominance=ParetoDominance()):
+    def __init__(self, parameters, alpha=0.01, beta=1.0, gamma=0.5, damping=0.9, dominance=ParetoDominance()):
         super().__init__()
         self.parameters = parameters
         self.dominance = dominance
@@ -1374,9 +1400,9 @@ class FireflyStep(Operator):
                 lb = param['bounds'][0]
                 ub = param['bounds'][1]
 
-                L = (ub-lb)
-                Gamma = L*self.gamma
-                alpha = self.a*L*0.9**iteration_nr
+                L = (ub - lb)
+                Gamma = L * self.gamma
+                alpha = self.a * L * 0.9 ** iteration_nr
 
                 # elementary distance of the particle, random walk
                 e = random.random() * (ub - lb)
@@ -1503,3 +1529,172 @@ class SimulatedBinaryCrossover(Crossover):
                             x1[i], x2[i] = c1, c2
 
         return Individual(x1, p1.features), Individual(x2, p2.features)
+
+
+class Normalization(Operator):
+
+    def __init__(self) -> None:
+        super().__init__()
+
+    @abstractmethod
+    def forward(self, X):
+        pass
+
+    @abstractmethod
+    def backward(self, X):
+        pass
+
+
+# ---- Useful if normalization is optional - can be simply disabled by using this object
+class NoNormalization(Normalization):
+
+    def forward(self, X):
+        return X
+
+    def backward(self, X):
+        return X
+
+
+class ZeroToOneNormalization(Normalization):
+
+    def __init__(self, xl=None, xu=None) -> None:
+        super().__init__()
+
+        # if both are None we are basically done because normalization is disabled
+        if xl is None and xu is None:
+            self.xl, self.xu = None, None
+            return
+
+        # if not set simply fall back no nan values
+        if xl is None:
+            xl = np.full_like(xu, np.nan)
+        if xu is None:
+            xu = np.full_like(xl, np.nan)
+
+        xl, xu = np.copy(xl).astype(float), np.copy(xu).astype(float)
+
+        # if both are equal then set the upper bound to none (always the 0 or lower bound will be returned then)
+        xu[xl == xu] = np.nan
+
+        # store the lower and upper bounds
+        self.xl, self.xu = xl, xu
+
+        # check out when the input values are nan
+        xl_nan, xu_nan = np.isnan(xl), np.isnan(xu)
+
+        # now create all the masks that are necessary
+        self.xl_only, self.xu_only = np.logical_and(~xl_nan, xu_nan), np.logical_and(xl_nan, ~xu_nan)
+        self.both_nan = np.logical_and(np.isnan(xl), np.isnan(xu))
+        self.neither_nan = ~self.both_nan
+
+        # if neither is nan than xu must be greater or equal than xl
+        any_nan = np.logical_or(np.isnan(xl), np.isnan(xu))
+        assert np.all(np.logical_or(xu >= xl, any_nan)), "xl must be less or equal than xu."
+
+    def forward(self, X):
+        if X is None or (self.xl is None and self.xu is None):
+            return X
+
+        xl, xu, xl_only, xu_only = self.xl, self.xu, self.xl_only, self.xu_only
+        both_nan, neither_nan = self.both_nan, self.neither_nan
+
+        # simple copy the input
+        N = np.copy(X)
+
+        # normalize between zero and one if neither of them is nan
+        N[..., neither_nan] = (X[..., neither_nan] - xl[neither_nan]) / (xu[neither_nan] - xl[neither_nan])
+
+        N[..., xl_only] = X[..., xl_only] - xl[xl_only]
+
+        N[..., xu_only] = 1.0 - (xu[xu_only] - X[..., xu_only])
+
+        return N
+
+    def backward(self, N):
+        if N is None or (self.xl is None and self.xu is None):
+            return N
+
+        xl, xu, xl_only, xu_only = self.xl, self.xu, self.xl_only, self.xu_only
+        both_nan, neither_nan = self.both_nan, self.neither_nan
+
+        X = N.copy()
+        X[..., neither_nan] = xl[neither_nan] + N[..., neither_nan] * (xu[neither_nan] - xl[neither_nan])
+
+        X[..., xl_only] = N[..., xl_only] + xl[xl_only]
+
+        X[..., xu_only] = xu[xu_only] - (1.0 - N[..., xu_only])
+
+        return X
+
+
+class Termination:
+
+    def __init__(self) -> None:
+        """
+        Base class for the implementation of a termination criterion for an algorithm.
+        """
+        super().__init__()
+
+        # the algorithm can be forced to terminate by setting this attribute to true
+        self.force_termination = False
+
+    def do_continue(self, algorithm):
+        """
+        Whenever the algorithm objects wants to know whether it should continue or not it simply
+        asks the termination criterion for it.
+        Parameters
+        ----------
+        algorithm : class
+            The algorithm object that is asking if it has terminated or not.
+        Returns
+        -------
+        do_continue : bool
+            Whether the algorithm has terminated or not.
+        """
+
+        if self.force_termination:
+            return False
+        else:
+            return self._do_continue(algorithm)
+
+    # the concrete implementation of the algorithm
+    def _do_continue(self, algorithm, **kwargs):
+        pass
+
+    def has_terminated(self, algorithm):
+        """
+        Instead of asking if the algorithm should continue it can also ask if it has terminated.
+        (just negates the continue method.)
+        """
+        return not self.do_continue(algorithm)
+
+
+class NoTermination(Termination):
+    def _do_continue(self, algorithm, **kwargs):
+        return True
+
+
+class MaximumGenerationTermination(Termination):
+
+    def __init__(self, n_max_gen) -> None:
+        super().__init__()
+        self.n_max_gen = n_max_gen
+
+        if self.n_max_gen is None:
+            self.n_max_gen = float("inf")
+
+    def _do_continue(self, algorithm, **kwargs):
+        return algorithm.n_gen < self.n_max_gen
+
+
+class MaximumFunctionCallTermination(Termination):
+
+    def __init__(self, n_max_evals) -> None:
+        super().__init__()
+        self.n_max_evals = n_max_evals
+
+        if self.n_max_evals is None:
+            self.n_max_evals = float("inf")
+
+    def _do_continue(self, algorithm, **kwargs):
+        return algorithm.evaluator.n_eval < self.n_max_evals
\ No newline at end of file
