@@ -2,9 +2,9 @@
  Module is dedicated to describe optimization problem.
 """
 
-from datastore import SqliteDataStore, DummyDataStore
-from utils import ConfigDictionary
-from artap.surrogate import SurrogateModelEval
+from .datastore import SqliteDataStore, DummyDataStore
+from .utils import ConfigDictionary
+from .surrogate import SurrogateModelEval
 from abc import abstractmethod
 
 import logging
@@ -95,7 +95,6 @@ class Problem:
                      "python": platform.python_version(),
                      "hostname": platform.node()}
 
-
         # populations
         self.individuals = []
         self.data_store = None
@@ -142,8 +141,6 @@ class Problem:
         return individuals
 
     def last_population(self):
-        # TODO: temporary solution - faster implementation with TinyDB
-
         # find max index
         max_index = -1
         for individual in self.individuals:
@@ -210,9 +207,10 @@ class Problem:
         """ :param individual: Individual """
         pass
 
-    def evaluate_constraints(self, individual):
-        """ :param individual: Individual """
-        pass
+    @abstractmethod
+    def evaluate_inequality_constraints(self, x):
+        """ :param x: vector """
+        return []
 
     def __setattr__(self, key, value):
         # if self.__is_frozen and not hasattr(self, key):
