@@ -33,7 +33,7 @@ class TestJob(unittest.TestCase):
         algorithm.options['max_processes'] = 2
         algorithm.run()
 
-        individuals = problem.populations[-1].individuals
+        individuals = problem.individuals
         # print(individuals)
 
         # values
@@ -52,7 +52,7 @@ class TestJob(unittest.TestCase):
         algorithm = SweepAlgorithm(problem, generator=gen)
         algorithm.run()
 
-        individuals = problem.populations[-1].individuals
+        individuals = problem.individuals
         self.assertEqual(individuals[0].costs, [9])
         self.assertEqual(individuals[1].costs, [22])
 
