@@ -53,7 +53,7 @@ class TestAckley(unittest.TestCase):
             algorithm.run()
 
             b = Results(problem)
-            optimum = b.find_optimum('F_1')  # Takes last cost function
+            optimum = b.find_optimum('f_1')  # Takes last cost function
             self.assertAlmostEqual(optimum.costs[0], problem.global_optimum, 1)
         except AssertionError:
             # stochastic
@@ -74,7 +74,7 @@ class TestAlpine(unittest.TestCase):
             algorithm.run()
 
             b = Results(problem)
-            optimum = b.find_optimum('F_1')  # Takes last cost function
+            optimum = b.find_optimum('f_1')  # Takes last cost function
             self.assertAlmostEqual(optimum.costs[0], problem.global_optimum, 1)
         except AssertionError:
             # stochastic
